You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cassandra.apache.org by mc...@apache.org on 2022/11/09 14:39:03 UTC

[cassandra-builds] branch trunk updated: For slow internets, retry mk-build-deps when debian package building, as it can time out too

This is an automated email from the ASF dual-hosted git repository.

mck pushed a commit to branch trunk
in repository https://gitbox.apache.org/repos/asf/cassandra-builds.git


The following commit(s) were added to refs/heads/trunk by this push:
     new ab06938  For slow internets, retry mk-build-deps when debian package building, as it can time out too
ab06938 is described below

commit ab06938814f39a850ba7fcc03d0dc3a24cac716b
Author: Mick Semb Wever <mc...@apache.org>
AuthorDate: Wed Nov 9 12:37:33 2022 +0100

    For slow internets, retry mk-build-deps when debian package building, as it can time out too
---
 docker/build-debs.sh | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/docker/build-debs.sh b/docker/build-debs.sh
index f9e5366..3bbe892 100755
--- a/docker/build-debs.sh
+++ b/docker/build-debs.sh
@@ -126,8 +126,10 @@ for x in $(seq 1 3); do
 done
 set -e
 
-# Install build dependencies and build package
-echo "y" | sudo mk-build-deps --install
+# Install build dependencies (retry if failed)
+until ( echo "y" | sudo mk-build-deps --install ) ; do echo "mk-build-deps failed… trying again after 10s… " ; sleep 10 ; done
+
+# build package
 dpkg-buildpackage -rfakeroot -uc -us
 
 # Copy created artifacts to dist dir mapped to docker host directory (must have proper permissions)


---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@cassandra.apache.org
For additional commands, e-mail: commits-help@cassandra.apache.org